@@ -28,11 +28,16 @@ public:
 
     void actionSelect();
 
+    void actionShowGui();
+    void actionSendKeyEsc();
+    void actionContextMenu();
+
 private slots:
     void commandActionFinished();
 
 private:
     void do_command_action(int action);
+    void do_send_key(int key);
 
     QNetworkAccessManager *m_manager;
 };
